diff --git a/core/modules/content_moderation/src/Form/EntityModerationForm.php b/core/modules/content_moderation/src/Form/EntityModerationForm.php
index ea2fedd010..5afa9546b0 100644
--- a/core/modules/content_moderation/src/Form/EntityModerationForm.php
+++ b/core/modules/content_moderation/src/Form/EntityModerationForm.php
@@ -140,7 +140,7 @@ public function submitForm(array &$form, FormStateInterface $form_state) {
     $new_state = $this->moderationInfo->getWorkflowForEntity($entity)->getState($new_state);
     // The page we're on likely won't be visible if we just set the entity to
     // the default state, as we hide that latest-revision tab if there is no
-    // forward revision. Redirect to the canonical URL instead, since that will
+    // draft revision. Redirect to the canonical URL instead, since that will
     // still exist.
     if ($new_state->isDefaultRevisionState()) {
       $form_state->setRedirectUrl($entity->toUrl('canonical'));
diff --git a/core/modules/content_moderation/src/ModerationInformation.php b/core/modules/content_moderation/src/ModerationInformation.php
index c20be5291f..6e052ad072 100644
--- a/core/modules/content_moderation/src/ModerationInformation.php
+++ b/core/modules/content_moderation/src/ModerationInformation.php
@@ -121,7 +121,7 @@ public function isLatestRevision(ContentEntityInterface $entity) {
   /**
    * {@inheritdoc}
    */
-  public function hasForwardRevision(ContentEntityInterface $entity) {
+  public function hasDraftRevision(ContentEntityInterface $entity) {
     return $this->isModeratedEntity($entity)
       && !($this->getLatestRevisionId($entity->getEntityTypeId(), $entity->id()) == $this->getDefaultRevisionId($entity->getEntityTypeId(), $entity->id()));
   }
diff --git a/core/modules/content_moderation/src/Routing/EntityModerationRouteProvider.php b/core/modules/content_moderation/src/Routing/EntityModerationRouteProvider.php
index e96f374a91..36ec1b1758 100644
--- a/core/modules/content_moderation/src/Routing/EntityModerationRouteProvider.php
+++ b/core/modules/content_moderation/src/Routing/EntityModerationRouteProvider.php
@@ -86,7 +86,7 @@ protected function getLatestVersionRoute(EntityTypeInterface $entity_type) {
         ->setOption('parameters', [
           $entity_type_id => [
             'type' => 'entity:' . $entity_type_id,
-            'load_forward_revision' => 1,
+            'load_draft_revision' => 1,
           ],
         ]);
 
diff --git a/core/modules/content_moderation/tests/src/Functional/ModerationFormTest.php b/core/modules/content_moderation/tests/src/Functional/ModerationFormTest.php
index 3882c764f1..e11b3555f2 100644
--- a/core/modules/content_moderation/tests/src/Functional/ModerationFormTest.php
+++ b/core/modules/content_moderation/tests/src/Functional/ModerationFormTest.php
@@ -24,9 +24,7 @@ protected function setUp() {
   /**
    * Tests the moderation form that shows on the latest version page.
    *
-   * The latest version page only shows if there is a forward revision. There
-   * is only a forward revision if a draft revision is created on a node where
-   * the default revision is not a published moderation state.
+   * The latest version page only shows if there is a draft revision.
    *
    * @see \Drupal\content_moderation\EntityOperations
    * @see \Drupal\Tests\content_moderation\Functional\ModerationStateBlockTest::testCustomBlockModeration
@@ -68,7 +66,7 @@ public function testModerationForm() {
     $this->assertField('edit-new-state', 'The node view page has a moderation form.');
 
     // The latest version page should not show, because there is still no
-    // forward revision.
+    // draft revision.
     $this->drupalGet($latest_version_path);
     $this->assertResponse(403);
 
@@ -84,11 +82,11 @@ public function testModerationForm() {
     $this->assertNoField('edit-new-state', 'The node view page has no moderation form.');
 
     // The latest version page should not show, because there is still no
-    // forward revision.
+    // draft revision.
     $this->drupalGet($latest_version_path);
     $this->assertResponse(403);
 
-    // Make a forward revision.
+    // Make a draft revision.
     $this->drupalPostForm($edit_path, [
       'body[0][value]' => 'Fourth version of the content.',
     ], t('Save and Create New Draft'));
@@ -100,7 +98,7 @@ public function testModerationForm() {
     $this->assertNoField('edit-new-state', 'The node view page has no moderation form.');
 
     // The latest version page should show the moderation form and have "Draft"
-    // status, because the forward revision is in "Draft".
+    // status, because the draft revision is in "Draft".
     $this->drupalGet($latest_version_path);
     $this->assertResponse(200);
     $this->assertField('edit-new-state', 'The latest-version page has a moderation form.');
@@ -112,7 +110,7 @@ public function testModerationForm() {
     ], t('Apply'));
 
     // The latest version page should not show, because there is no
-    // forward revision.
+    // draft revision.
     $this->drupalGet($latest_version_path);
     $this->assertResponse(403);
   }
@@ -138,7 +136,7 @@ public function testNonBundleModerationForm() {
     $this->drupalPostForm('entity_test_mulrevpub/manage/1/edit', [], t('Save and Create New Draft'));
 
     // The latest version page should not show, because there is still no
-    // forward revision.
+    // draft revision.
     $this->drupalGet('/entity_test_mulrevpub/manage/1/latest');
     $this->assertResponse(403);
 
@@ -152,11 +150,11 @@ public function testNonBundleModerationForm() {
     $this->assertNoText('Status', 'The node view page has no moderation form.');
 
     // The latest version page should not show, because there is still no
-    // forward revision.
+    // draft revision.
     $this->drupalGet('entity_test_mulrevpub/manage/1/latest');
     $this->assertResponse(403);
 
-    // Make a forward revision.
+    // Make a draft revision.
     $this->drupalPostForm('entity_test_mulrevpub/manage/1/edit', [], t('Save and Create New Draft'));
 
     // The published view should not have a moderation form, because it is the
@@ -166,7 +164,7 @@ public function testNonBundleModerationForm() {
     $this->assertNoText('Status', 'The node view page has no moderation form.');
 
     // The latest version page should show the moderation form and have "Draft"
-    // status, because the forward revision is in "Draft".
+    // status, because the draft revision is in "Draft".
     $this->drupalGet('entity_test_mulrevpub/manage/1/latest');
     $this->assertResponse(200);
     $this->assertText('Status', 'Form text found on the latest-version page.');
@@ -178,7 +176,7 @@ public function testNonBundleModerationForm() {
     ], t('Apply'));
 
     // The latest version page should not show, because there is no
-    // forward revision.
+    // draft revision.
     $this->drupalGet('entity_test_mulrevpub/manage/1/latest');
     $this->assertResponse(403);
   }
@@ -189,7 +187,7 @@ public function testNonBundleModerationForm() {
   public function testModerationFormSetsRevisionAuthor() {
     // Create new moderated content in published.
     $node = $this->createNode(['type' => 'moderated_content', 'moderation_state' => 'published']);
-    // Make a forward revision.
+    // Make a draft revision.
     $node->title = $this->randomMachineName();
     $node->moderation_state->value = 'draft';
     $node->save();
diff --git a/core/modules/content_moderation/tests/src/Functional/ModerationLocaleTest.php b/core/modules/content_moderation/tests/src/Functional/ModerationLocaleTest.php
index a9d95f0b9f..9b737316af 100644
--- a/core/modules/content_moderation/tests/src/Functional/ModerationLocaleTest.php
+++ b/core/modules/content_moderation/tests/src/Functional/ModerationLocaleTest.php
@@ -196,7 +196,7 @@ public function testTranslateModeratedContent() {
     $this->assertTrue($french_node->isPublished());
     $this->assertFalse($english_node->isPublished());
 
-    // Create a forward revision
+    // Create a draft revision
     $this->drupalPostForm('fr/node/' . $english_node->id() . '/edit', [], t('Save and Create New Draft (this translation)'));
     $english_node = $this->drupalGetNodeByTitle('An english node', TRUE);
     $french_node = $english_node->getTranslation('fr');
diff --git a/core/modules/content_moderation/tests/src/Functional/ModerationStateNodeTest.php b/core/modules/content_moderation/tests/src/Functional/ModerationStateNodeTest.php
index 277acdfadd..7d88458a5e 100644
--- a/core/modules/content_moderation/tests/src/Functional/ModerationStateNodeTest.php
+++ b/core/modules/content_moderation/tests/src/Functional/ModerationStateNodeTest.php
@@ -105,7 +105,7 @@ public function testFormSaveDestination() {
     $this->assertUrl(Url::fromRoute('entity.node.canonical', ['node' => $node->id()]));
     $this->assertText('Third version of the content.');
 
-    // Make a new forward revision; after saving, we should be on the "Latest
+    // Make a new draft revision; after saving, we should be on the "Latest
     // version" tab.
     $this->drupalPostForm($edit_path, [
       'body[0][value]' => 'Fourth version of the content.',
diff --git a/core/modules/content_moderation/tests/src/Functional/NodeAccessTest.php b/core/modules/content_moderation/tests/src/Functional/NodeAccessTest.php
index eeac1cea93..b6f9bced49 100644
--- a/core/modules/content_moderation/tests/src/Functional/NodeAccessTest.php
+++ b/core/modules/content_moderation/tests/src/Functional/NodeAccessTest.php
@@ -116,7 +116,7 @@ public function testPageAccess() {
     $this->drupalGet($view_path);
     $this->assertResponse(200);
 
-    // Create a forward revision for the 'Latest revision' tab.
+    // Create a draft revision for the 'Latest revision' tab.
     $this->drupalLogin($this->adminUser);
     $this->drupalPostForm($edit_path, [
       'title[0][value]' => 'moderated content revised',
@@ -132,7 +132,7 @@ public function testPageAccess() {
     $this->drupalGet($view_path);
     $this->assertResponse(200);
 
-    // Now make another user, who should not be able to see forward revisions.
+    // Now make another user, who should not be able to see draft revisions.
     $user = $this->createUser([
       'use editorial transition create_new_draft',
     ]);
diff --git a/core/modules/node/src/Tests/PagePreviewTest.php b/core/modules/node/src/Tests/PagePreviewTest.php
index 37b00d3b48..226aae82eb 100644
--- a/core/modules/node/src/Tests/PagePreviewTest.php
+++ b/core/modules/node/src/Tests/PagePreviewTest.php
@@ -427,14 +427,14 @@ public function testPagePreviewWithRevisions() {
     $this->assertFieldByName('revision_log[0][value]', $edit['revision_log[0][value]'], 'Revision log field displayed.');
 
     // Save the node after coming back from the preview page so we can create a
-    // forward revision for it.
+    // draft revision for it.
     $this->drupalPostForm(NULL, [], t('Save'));
     $node = $this->drupalGetNodeByTitle($edit[$title_key]);
 
-    // Check that previewing a forward revision of a node works. This can not be
+    // Check that previewing a draft revision of a node works. This can not be
     // accomplished through the UI so we have to use API calls.
     // @todo Change this test to use the UI when we will be able to create
-    // forward revisions in core.
+    // draft revisions in core.
     // @see https://www.drupal.org/node/2725533
     $node->setNewRevision(TRUE);
     $node->isDefaultRevision(FALSE);
diff --git a/core/modules/system/tests/src/Functional/Entity/EntityRevisionsTest.php b/core/modules/system/tests/src/Functional/Entity/EntityRevisionsTest.php
index 38db0e9dc0..c8e9e47ca8 100644
--- a/core/modules/system/tests/src/Functional/Entity/EntityRevisionsTest.php
+++ b/core/modules/system/tests/src/Functional/Entity/EntityRevisionsTest.php
@@ -135,28 +135,28 @@ public function testEntityRevisionParamConverter() {
     $entity->addTranslation('de', ['name' => 'default revision - de']);
     $entity->save();
 
-    $forward_revision = \Drupal::entityTypeManager()->getStorage('entity_test_mulrev')->loadUnchanged($entity->id());
+    $draft_revision = \Drupal::entityTypeManager()->getStorage('entity_test_mulrev')->loadUnchanged($entity->id());
 
-    $forward_revision->setNewRevision();
-    $forward_revision->isDefaultRevision(FALSE);
+    $draft_revision->setNewRevision();
+    $draft_revision->isDefaultRevision(FALSE);
 
-    $forward_revision->name = 'forward revision - en';
-    $forward_revision->save();
+    $draft_revision->name = 'draft revision - en';
+    $draft_revision->save();
 
-    $forward_revision_translation = $forward_revision->getTranslation('de');
-    $forward_revision_translation->name = 'forward revision - de';
-    $forward_revision_translation->save();
+    $draft_revision_translation = $draft_revision->getTranslation('de');
+    $draft_revision_translation->name = 'draft revision - de';
+    $draft_revision_translation->save();
 
     // Check that the entity revision is upcasted in the correct language.
-    $revision_url = 'entity_test_mulrev/' . $entity->id() . '/revision/' . $forward_revision->getRevisionId() . '/view';
+    $revision_url = 'entity_test_mulrev/' . $entity->id() . '/revision/' . $draft_revision->getRevisionId() . '/view';
 
     $this->drupalGet($revision_url);
-    $this->assertText('forward revision - en');
-    $this->assertNoText('forward revision - de');
+    $this->assertText('draft revision - en');
+    $this->assertNoText('draft revision - de');
 
     $this->drupalGet('de/' . $revision_url);
-    $this->assertText('forward revision - de');
-    $this->assertNoText('forward revision - en');
+    $this->assertText('draft revision - de');
+    $this->assertNoText('draft revision - en');
   }
 
 }
diff --git a/core/modules/views/tests/src/Kernel/Plugin/SqlEntityLoadingTest.php b/core/modules/views/tests/src/Kernel/Plugin/SqlEntityLoadingTest.php
index 339638ceb2..7dfd22386c 100644
--- a/core/modules/views/tests/src/Kernel/Plugin/SqlEntityLoadingTest.php
+++ b/core/modules/views/tests/src/Kernel/Plugin/SqlEntityLoadingTest.php
@@ -37,7 +37,7 @@ protected function setUp($import_test_views = TRUE) {
     $this->installSchema('node', 'node_access');
   }
 
-  public function testViewWithNonDefaultForwardRevision() {
+  public function testViewWithNonDefaultDraftRevision() {
     $node_type = NodeType::create([
       'type' => 'page',
     ]);
diff --git a/core/modules/content_moderation/src/Access/LatestRevisionCheck.php b/core/modules/content_moderation/src/Access/LatestRevisionCheck.php
index db0cde459f..3179841d3a 100644
--- a/core/modules/content_moderation/src/Access/LatestRevisionCheck.php
+++ b/core/modules/content_moderation/src/Access/LatestRevisionCheck.php
@@ -34,7 +34,7 @@ public function __construct(ModerationInformationInterface $moderation_informati
   }
 
   /**
    * Checks that there is a forward revision available.
    *
    * This checker assumes the presence of an '_entity_access' requirement key
    * in the same form as used by EntityAccessCheck.
@@ -54,7 +54,7 @@ public function __construct(ModerationInformationInterface $moderation_informati
   public function access(Route $route, RouteMatchInterface $route_match, AccountInterface $account) {
     // This tab should not show up unless there's a reason to show it.
     $entity = $this->loadEntity($route, $route_match);
-    if ($this->moderationInfo->hasForwardRevision($entity)) {
+    if ($this->moderationInfo->hasDraftRevision($entity)) {
       // Check the global permissions first.
       $access_result = AccessResult::allowedIfHasPermissions($account, ['view latest version', 'view any unpublished content']);
       if (!$access_result->isAllowed()) {
@@ -34,7 +34,7 @@ public function __construct(ModerationInformationInterface $moderation_informati
 
   /**
-   * Checks that there is a forward revision available.
+   * Checks that there is a draft revision available.
    *
    * This checker assumes the presence of an '_entity_access' requirement key
diff --git a/core/modules/content_moderation/src/EntityTypeInfo.php b/core/modules/content_moderation/src/EntityTypeInfo.php
index 8f6ac4d79e..be4a9cc583 100644
--- a/core/modules/content_moderation/src/EntityTypeInfo.php
+++ b/core/modules/content_moderation/src/EntityTypeInfo.php
@@ -295,7 +295,7 @@ public function formAlter(array &$form, FormStateInterface $form_state, $form_id
   }
 
   /**
    * Redirect content entity edit forms on save, if there is a forward revision.
    *
    * When saving their changes, editors should see those changes displayed on
    * the next page.
@@ -310,7 +310,7 @@ public static function bundleFormRedirect(array &$form, FormStateInterface $form
     $entity = $form_state->getFormObject()->getEntity();
 
     $moderation_info = \Drupal::getContainer()->get('content_moderation.moderation_information');
-    if ($moderation_info->hasForwardRevision($entity) && $entity->hasLinkTemplate('latest-version')) {
+    if ($moderation_info->hasDraftRevision($entity) && $entity->hasLinkTemplate('latest-version')) {
       $entity_type_id = $entity->getEntityTypeId();
       $form_state->setRedirect("entity.$entity_type_id.latest_version", [$entity_type_id => $entity->id()]);
     }
@@ -295,7 +295,7 @@ public function formAlter(array &$form, FormStateInterface $form_state, $form_id
 
   /**
-   * Redirect content entity edit forms on save, if there is a forward revision.
+   * Redirect content entity edit forms on save, if there is a draft revision.
    *
    * When saving their changes, editors should see those changes displayed on
diff --git a/core/modules/content_moderation/src/ModerationInformationInterface.php b/core/modules/content_moderation/src/ModerationInformationInterface.php
index 862987f8d8..a7b28359cc 100644
--- a/core/modules/content_moderation/src/ModerationInformationInterface.php
+++ b/core/modules/content_moderation/src/ModerationInformationInterface.php
@@ -102,15 +102,15 @@ public function getDefaultRevisionId($entity_type_id, $entity_id);
   public function isLatestRevision(ContentEntityInterface $entity);
 
   /**
    * Determines if a forward revision exists for the specified entity.
    *
    * @param \Drupal\Core\Entity\ContentEntityInterface $entity
    *   The entity which may or may not have a forward revision.
    *
    * @return bool
    *   TRUE if this entity has forward revisions available, FALSE otherwise.
    */
-  public function hasForwardRevision(ContentEntityInterface $entity);
+  public function hasDraftRevision(ContentEntityInterface $entity);
 
   /**
    * Determines if an entity is "live".
@@ -102,15 +102,15 @@ public function getDefaultRevisionId($entity_type_id, $entity_id);
 
   /**
-   * Determines if a forward revision exists for the specified entity.
+   * Determines if a draft revision exists for the specified entity.
    *
    * @param \Drupal\Core\Entity\ContentEntityInterface $entity
@@ -102,15 +102,15 @@ public function getDefaultRevisionId($entity_type_id, $entity_id);
    *
    * @param \Drupal\Core\Entity\ContentEntityInterface $entity
-   *   The entity which may or may not have a forward revision.
+   *   The entity which may or may not have a draft revision.
    *
    * @return bool
@@ -102,15 +102,15 @@ public function getDefaultRevisionId($entity_type_id, $entity_id);
    *
    * @return bool
-   *   TRUE if this entity has forward revisions available, FALSE otherwise.
+   *   TRUE if this entity has draft revisions available, FALSE otherwise.
    */
diff --git a/core/modules/content_moderation/src/ParamConverter/EntityRevisionConverter.php b/core/modules/content_moderation/src/ParamConverter/EntityRevisionConverter.php
index eac1913fca..04756fc27e 100644
--- a/core/modules/content_moderation/src/ParamConverter/EntityRevisionConverter.php
+++ b/core/modules/content_moderation/src/ParamConverter/EntityRevisionConverter.php
@@ -41,23 +41,23 @@ public function __construct(EntityManagerInterface $entity_manager, ModerationIn
    * {@inheritdoc}
    */
   public function applies($definition, $name, Route $route) {
-    return $this->hasForwardRevisionFlag($definition) || $this->isEditFormPage($route);
+    return $this->hasDraftRevisionFlag($definition) || $this->isEditFormPage($route);
   }
 
   /**
    * Determines if the route definition includes a forward-revision flag.
    *
    * This is a custom flag defined by the Content Moderation module to load
    * forward revisions rather than the default revision on a given route.
    *
    * @param array $definition
    *   The parameter definition provided in the route options.
    *
    * @return bool
    *   TRUE if the forward revision flag is set, FALSE otherwise.
    */
-  protected function hasForwardRevisionFlag(array $definition) {
-    return (isset($definition['load_forward_revision']) && $definition['load_forward_revision']);
+  protected function hasDraftRevisionFlag(array $definition) {
+    return (isset($definition['load_draft_revision']) && $definition['load_draft_revision']);
   }
 
   /**
@@ -41,23 +41,23 @@ public function __construct(EntityManagerInterface $entity_manager, ModerationIn
 
   /**
-   * Determines if the route definition includes a forward-revision flag.
+   * Determines if the route definition includes a draft revision flag.
    *
    * This is a custom flag defined by the Content Moderation module to load
@@ -41,23 +41,23 @@ public function __construct(EntityManagerInterface $entity_manager, ModerationIn
    *
    * This is a custom flag defined by the Content Moderation module to load
-   * forward revisions rather than the default revision on a given route.
+   * draft revisions rather than the default revision on a given route.
    *
    * @param array $definition
@@ -41,23 +41,23 @@ public function __construct(EntityManagerInterface $entity_manager, ModerationIn
    *
    * @return bool
-   *   TRUE if the forward revision flag is set, FALSE otherwise.
+   *   TRUE if the draft revision flag is set, FALSE otherwise.
    */
diff --git a/core/modules/content_moderation/tests/src/Functional/ModerationStateBlockTest.php b/core/modules/content_moderation/tests/src/Functional/ModerationStateBlockTest.php
index 1a8f78c504..4fc285807e 100644
--- a/core/modules/content_moderation/tests/src/Functional/ModerationStateBlockTest.php
+++ b/core/modules/content_moderation/tests/src/Functional/ModerationStateBlockTest.php
@@ -93,18 +93,18 @@ public function testCustomBlockModeration() {
     $this->drupalGet('');
     $this->assertText($updated_body);
 
     // Publish the block so we can create a forward revision.
     $this->drupalPostForm('block/' . $block->id(), [], t('Save and Publish'));
 
-    // Create a forward revision.
-    $forward_revision_body = 'This is the forward revision body value';
+    // Create a draft revision.
+    $draft_revision_body = 'This is the draft revision body value';
     $edit = [
-      'body[0][value]' => $forward_revision_body,
+      'body[0][value]' => $draft_revision_body,
     ];
     $this->drupalPostForm('block/' . $block->id(), $edit, t('Save and Create New Draft'));
     $this->assertText(t('basic Moderated block has been updated.'));
 
     // Navigate to home page and check that the forward revision doesn't show,
     // since it should not be set as the default revision.
     $this->drupalGet('');
     $this->assertText($updated_body);
@@ -116,10 +116,10 @@ public function testCustomBlockModeration() {
     $this->drupalPostForm('block/' . $block->id() . '/latest', $edit, t('Apply'));
     $this->assertText(t('The moderation state has been updated.'));
 
     // Navigate to home page and check that the forward revision is now the
     // default revision and therefore visible.
     $this->drupalGet('');
-    $this->assertText($forward_revision_body);
+    $this->assertText($draft_revision_body);
   }
 
 }
@@ -93,18 +93,18 @@ public function testCustomBlockModeration() {
     $this->assertText($updated_body);
 
-    // Publish the block so we can create a forward revision.
+    // Publish the block so we can create a draft revision.
     $this->drupalPostForm('block/' . $block->id(), [], t('Save and Publish'));
 
@@ -93,18 +93,18 @@ public function testCustomBlockModeration() {
     $this->assertText(t('basic Moderated block has been updated.'));
 
-    // Navigate to home page and check that the forward revision doesn't show,
+    // Navigate to home page and check that the draft revision doesn't show,
     // since it should not be set as the default revision.
     $this->drupalGet('');
@@ -116,10 +116,10 @@ public function testCustomBlockModeration() {
     $this->assertText(t('The moderation state has been updated.'));
 
-    // Navigate to home page and check that the forward revision is now the
+    // Navigate to home page and check that the draft revision is now the
     // default revision and therefore visible.
     $this->drupalGet('');
diff --git a/core/modules/content_moderation/tests/src/Kernel/EntityOperationsTest.php b/core/modules/content_moderation/tests/src/Kernel/EntityOperationsTest.php
index 60e9edf648..986f0a01c0 100644
--- a/core/modules/content_moderation/tests/src/Kernel/EntityOperationsTest.php
+++ b/core/modules/content_moderation/tests/src/Kernel/EntityOperationsTest.php
@@ -55,9 +55,9 @@ protected function createNodeType() {
   }
 
   /**
    * Verifies that the process of saving forward-revisions works as expected.
    */
-  public function testForwardRevisions() {
+  public function testDraftRevisions() {
     // Create a new node in draft.
     $page = Node::create([
       'type' => 'page',
@@ -87,7 +87,7 @@ public function testForwardRevisions() {
     $this->assertTrue($page->isDefaultRevision());
     $this->assertTrue($page->isPublished());
 
-    // Make a new forward-revision in Draft.
+    // Make a new draft revision in Draft.
     $page->setTitle('C');
     $page->moderation_state->value = 'draft';
     $page->save();
@@ -96,7 +96,7 @@ public function testForwardRevisions() {
     $page = Node::load($id);
     $this->assertEquals('B', $page->getTitle());
 
     // Verify we can load the forward revision, even if the mechanism is kind
     // of gross. Note: revisionIds() is only available on NodeStorageInterface,
     // so this won't work for non-nodes. We'd need to use entity queries. This
     // is a core bug that should get fixed.
@@ -55,9 +55,9 @@ protected function createNodeType() {
 
   /**
-   * Verifies that the process of saving forward-revisions works as expected.
+   * Verifies that the process of saving draft revisions works as expected.
    */
@@ -96,7 +96,7 @@ public function testForwardRevisions() {
     $this->assertEquals('B', $page->getTitle());
 
-    // Verify we can load the forward revision, even if the mechanism is kind
+    // Verify we can load the draft revision, even if the mechanism is kind
     // of gross. Note: revisionIds() is only available on NodeStorageInterface,
     // so this won't work for non-nodes. We'd need to use entity queries. This
diff --git a/core/modules/content_moderation/tests/src/Unit/LatestRevisionCheckTest.php b/core/modules/content_moderation/tests/src/Unit/LatestRevisionCheckTest.php
index 2d33ee8ec4..59f76e7870 100644
--- a/core/modules/content_moderation/tests/src/Unit/LatestRevisionCheckTest.php
+++ b/core/modules/content_moderation/tests/src/Unit/LatestRevisionCheckTest.php
@@ -46,7 +46,7 @@ protected function setUp() {
    * @param string $entity_type
    *   The machine name of the entity to mock.
    * @param bool $has_forward
    *   Whether this entity should have a forward revision in the system.
    * @param array $account_permissions
    *   An array of permissions the account has.
    * @param bool $is_owner
@@ -82,7 +82,7 @@ public function testLatestAccessPermissions($entity_class, $entity_type, $has_fo
 
     /** @var \Drupal\content_moderation\ModerationInformation $mod_info */
     $mod_info = $this->prophesize(ModerationInformation::class);
-    $mod_info->hasForwardRevision($entity->reveal())->willReturn($has_forward);
+    $mod_info->hasDraftRevision($entity->reveal())->willReturn($has_forward);
 
     $route = $this->prophesize(Route::class);
 
@@ -119,13 +119,13 @@ public function accessSituationProvider() {
       // Node with own content permissions and no latest version, but no perms
       // to view latest version.
       [Node::class, 'node', TRUE, ['view own unpublished content'], FALSE, AccessResultNeutral::class],
       // Block with forward revision, and permissions to view any.
       [BlockContent::class, 'block_content', TRUE, ['view latest version', 'view any unpublished content'], FALSE, AccessResultAllowed::class],
       // Block with no forward revision.
       [BlockContent::class, 'block_content', FALSE, ['view latest version', 'view any unpublished content'], FALSE, AccessResultForbidden::class],
       // Block with forward revision, but no permission to view any.
       [BlockContent::class, 'block_content', TRUE, ['view latest version', 'view own unpublished content'], FALSE, AccessResultNeutral::class],
       // Block with no forward revision.
       [BlockContent::class, 'block_content', FALSE, ['view latest version', 'view own unpublished content'], FALSE, AccessResultForbidden::class],
     ];
   }
@@ -46,7 +46,7 @@ protected function setUp() {
    *   The machine name of the entity to mock.
    * @param bool $has_forward
-   *   Whether this entity should have a forward revision in the system.
+   *   Whether this entity should have a draft revision in the system.
    * @param array $account_permissions
    *   An array of permissions the account has.
@@ -119,13 +119,13 @@ public function accessSituationProvider() {
       // to view latest version.
       [Node::class, 'node', TRUE, ['view own unpublished content'], FALSE, AccessResultNeutral::class],
-      // Block with forward revision, and permissions to view any.
+      // Block with draft revision, and permissions to view any.
       [BlockContent::class, 'block_content', TRUE, ['view latest version', 'view any unpublished content'], FALSE, AccessResultAllowed::class],
@@ -119,13 +119,13 @@ public function accessSituationProvider() {
       [BlockContent::class, 'block_content', TRUE, ['view latest version', 'view any unpublished content'], FALSE, AccessResultAllowed::class],
-      // Block with no forward revision.
+      // Block with no draft revision.
       [BlockContent::class, 'block_content', FALSE, ['view latest version', 'view any unpublished content'], FALSE, AccessResultForbidden::class],
@@ -119,13 +119,13 @@ public function accessSituationProvider() {
       [BlockContent::class, 'block_content', FALSE, ['view latest version', 'view any unpublished content'], FALSE, AccessResultForbidden::class],
-      // Block with forward revision, but no permission to view any.
+      // Block with draft revision, but no permission to view any.
       [BlockContent::class, 'block_content', TRUE, ['view latest version', 'view own unpublished content'], FALSE, AccessResultNeutral::class],
@@ -119,13 +119,13 @@ public function accessSituationProvider() {
       [BlockContent::class, 'block_content', TRUE, ['view latest version', 'view own unpublished content'], FALSE, AccessResultNeutral::class],
-      // Block with no forward revision.
+      // Block with no draft revision.
       [BlockContent::class, 'block_content', FALSE, ['view latest version', 'view own unpublished content'], FALSE, AccessResultForbidden::class],
     ];
diff --git a/core/modules/taxonomy/tests/src/Kernel/ForwardRevisionTest.php b/core/modules/taxonomy/tests/src/Kernel/DraftRevisionTest.php
similarity index 90%
rename from core/modules/taxonomy/tests/src/Kernel/ForwardRevisionTest.php
rename to core/modules/taxonomy/tests/src/Kernel/DraftRevisionTest.php
index abc0846fc5..5eca9f7720 100644
--- a/core/modules/taxonomy/tests/src/Kernel/ForwardRevisionTest.php
+++ b/core/modules/taxonomy/tests/src/Kernel/DraftRevisionTest.php
@@ -11,11 +11,11 @@
 use Drupal\taxonomy\Entity\Vocabulary;
 
 /**
  * Kernel tests for taxonomy forward revisions.
  *
  * @group taxonomy
  */
-class ForwardRevisionTest extends KernelTestBase {
+class DraftRevisionTest extends KernelTestBase {
 
   /**
    * {@inheritdoc}
@@ -35,9 +35,9 @@ protected function setUp() {
   }
 
   /**
    * Tests that the taxonomy index work correctly with forward revisions.
    */
-  public function testTaxonomyIndexWithForwardRevision() {
+  public function testTaxonomyIndexWithDraftRevision() {
     \Drupal::configFactory()->getEditable('taxonomy.settings')->set('maintain_index_table', TRUE)->save();
 
     Vocabulary::create([
@@ -102,7 +102,7 @@ public function testTaxonomyIndexWithForwardRevision() {
     $taxonomy_index = $this->getTaxonomyIndex();
     $this->assertEquals($term2->id(), $taxonomy_index[$node->id()]->tid);
 
     // Check that making the previously created forward-revision the default
     // revision updates the taxonomy index correctly.
     $node->isDefaultRevision(TRUE);
     $node->save();
@@ -11,11 +11,11 @@
 
 /**
- * Kernel tests for taxonomy forward revisions.
+ * Kernel tests for taxonomy draft revisions.
  *
  * @group taxonomy
@@ -35,9 +35,9 @@ protected function setUp() {
 
   /**
-   * Tests that the taxonomy index work correctly with forward revisions.
+   * Tests that the taxonomy index work correctly with draft revisions.
    */
@@ -102,7 +102,7 @@ public function testTaxonomyIndexWithForwardRevision() {
     $this->assertEquals($term2->id(), $taxonomy_index[$node->id()]->tid);
 
-    // Check that making the previously created forward-revision the default
+    // Check that making the previously created draft revision the default
     // revision updates the taxonomy index correctly.
     $node->isDefaultRevision(TRUE);
diff --git a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
index 5c7e51cbc5..85cbe8ea10 100644
--- a/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Entity/EntityQueryTest.php
@@ -887,9 +887,9 @@ public function testBaseFieldMultipleColumns() {
   }
 
   /**
-   * Test forward-revisions.
+   * Test draft revisions.
    */
-  public function testForwardRevisions() {
+  public function testDraftRevisions() {
     // Ensure entity 14 is returned.
     $result = \Drupal::entityQuery('entity_test_mulrev')
       ->condition('id', [14], 'IN')
@@ -914,7 +914,7 @@ public function testForwardRevisions() {
       ->execute();
     $this->assertEqual(count($result), 1);
 
     // Verify that field conditions on the default and forward revision are
     // work as expected.
     $result = \Drupal::entityQuery('entity_test_mulrev')
       ->condition('id', [14], 'IN')
@@ -914,7 +914,7 @@ public function testForwardRevisions() {
     $this->assertEqual(count($result), 1);
 
-    // Verify that field conditions on the default and forward revision are
+    // Verify that field conditions on the default and draft revision are
     // work as expected.
     $result = \Drupal::entityQuery('entity_test_mulrev')
diff --git a/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php b/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php
index 5c0ef7b382..80e2e421c2 100644
--- a/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php
+++ b/core/tests/Drupal/KernelTests/Core/Entity/EntityRevisionTranslationTest.php
@@ -88,9 +88,9 @@ public function testRevertRevisionAfterTranslation() {
   }
 
   /**
    * Tests the translation values when saving a forward revision.
    */
-  public function testTranslationValuesWhenSavingForwardRevisions() {
+  public function testTranslationValuesWhenSavingDraftRevisions() {
     $user = $this->createUser();
     $storage = $this->entityManager->getStorage('entity_test_mulrev');
 
@@ -103,33 +103,33 @@ public function testTranslationValuesWhenSavingForwardRevisions() {
     $entity->addTranslation('de', ['name' => 'default revision - de']);
     $entity->save();
 
     // Create a forward revision for the entity and change a field value for
     // both languages.
-    $forward_revision = $this->reloadEntity($entity);
+    $draft_revision = $this->reloadEntity($entity);
 
-    $forward_revision->setNewRevision();
-    $forward_revision->isDefaultRevision(FALSE);
+    $draft_revision->setNewRevision();
+    $draft_revision->isDefaultRevision(FALSE);
 
-    $forward_revision->name = 'forward revision - en';
-    $forward_revision->save();
+    $draft_revision->name = 'draft revision - en';
+    $draft_revision->save();
 
-    $forward_revision_translation = $forward_revision->getTranslation('de');
-    $forward_revision_translation->name = 'forward revision - de';
-    $forward_revision_translation->save();
+    $draft_revision_translation = $draft_revision->getTranslation('de');
+    $draft_revision_translation->name = 'draft revision - de';
+    $draft_revision_translation->save();
 
-    $forward_revision_id = $forward_revision->getRevisionId();
-    $forward_revision = $storage->loadRevision($forward_revision_id);
+    $draft_revision_id = $draft_revision->getRevisionId();
+    $draft_revision = $storage->loadRevision($draft_revision_id);
 
     // Change the value of the field in the default language, save the forward
     // revision and check that the value of the field in the second language is
-    // also taken from the forward revision, *not* from the default revision.
-    $forward_revision->name = 'updated forward revision - en';
-    $forward_revision->save();
+    // also taken from the draft revision, *not* from the default revision.
+    $draft_revision->name = 'updated draft revision - en';
+    $draft_revision->save();
 
-    $forward_revision = $storage->loadRevision($forward_revision_id);
+    $draft_revision = $storage->loadRevision($draft_revision_id);
 
-    $this->assertEquals($forward_revision->name->value, 'updated forward revision - en');
-    $this->assertEquals($forward_revision->getTranslation('de')->name->value, 'forward revision - de');
+    $this->assertEquals($draft_revision->name->value, 'updated draft revision - en');
+    $this->assertEquals($draft_revision->getTranslation('de')->name->value, 'draft revision - de');
   }
 
   /**
@@ -88,9 +88,9 @@ public function testRevertRevisionAfterTranslation() {
 
   /**
-   * Tests the translation values when saving a forward revision.
+   * Tests the translation values when saving a draft revision.
    */
@@ -103,33 +103,33 @@ public function testTranslationValuesWhenSavingForwardRevisions() {
     $entity->save();
 
-    // Create a forward revision for the entity and change a field value for
+    // Create a draft revision for the entity and change a field value for
     // both languages.
